@@ -46,19 +46,27 @@ def write_default_ansible_cfg(work_dir,
     shutil.copy(base_ansible_cfg, ansible_config_path)
 
     modules_path = ('/root/.ansible/plugins/modules:'
+                    '/usr/share/ansible/tripleo-plugins/modules:'
                     '/usr/share/ansible/plugins/modules:'
                     '%s/library' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     lookups_path = (
         'root/.ansible/plugins/lookup:'
+        '/usr/share/ansible/tripleo-plugins/lookup:'
         '/usr/share/ansible/plugins/lookup:'
         '%s/lookup_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     callbacks_path = (
         '~/.ansible/plugins/callback:'
+        '/usr/share/ansible/tripleo-plugins/callback:'
         '/usr/share/ansible/plugins/callback:'
         '%s/callback_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
-    callbacks_whitelist = ','.join(['profile_tasks'])
+    action_plugins_path = (
+        '~/.ansible/plugins/action:'
+        '/usr/share/ansible/plugins/action:'
+        '/usr/share/ansible/tripleo-plugins/action:'
+        '%s/action_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     roles_path = ('%(work_dir)s/roles:'
                   '/root/.ansible/roles:'
+                  '/usr/share/ansible/tripleo-roles:'
                   '/usr/share/ansible/roles:'
                   '/etc/ansible/roles:'
                   '%(ooo_val_path)s/roles:'
@@ -74,10 +82,8 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'roles_path', roles_path)
     config.set('defaults', 'library', modules_path)
     config.set('defaults', 'callback_plugins', callbacks_path)
-    config.set('defaults', 'callback_whitelist', callbacks_whitelist)
+    config.set('defaults', 'action_plugins', action_plugins_path)
     config.set('defaults', 'lookup_plugins', lookups_path)
-    # suppress tasks if all hosts skip, was previously full_skip callback
-    config.set('defaults', 'display_skipped_hosts', 'no')
 
     log_path = os.path.join(work_dir, 'ansible.log')
     config.set('defaults', 'log_path', log_path)
@@ -90,15 +96,6 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'timeout', '30')
     config.set('defaults', 'gather_timeout', '30')
 
-    # Setup fact cache to improve playbook execution speed
-    config.set('defaults', 'gathering', 'smart')
-    config.set('defaults', 'fact_caching', 'jsonfile')
-    config.set('defaults', 'fact_caching_connection',
-               '/var/lib/mistral/ansible_fact_cache')
-
-    # Expire facts in the fact cache after 7200s (2h)
-    config.set('defaults', 'fact_caching_timeout', '7200')
-
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
                '-o UserKnownHostsFile=/dev/null '
@@ -637,9 +634,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 *command, cwd=self.work_dir,
                 env_variables=env_variables,
                 log_errors=processutils.LogErrors.ALL)
-            if self.trash_output:
-                stdout = ""
-                stderr = ""
             return {"stderr": stderr, "stdout": stdout,
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
