@@ -110,6 +110,8 @@ class CheckExistingInstancesAction(base.TripleOAction):
         not_found = []
         found = []
         for request in self.instances:
+            if 'hostname' not in request:
+                continue
             try:
                 instance = provisioner.show_instance(request['hostname'])
             # TODO(dtantsur): replace Error with a specific exception
@@ -333,7 +335,8 @@ class ExpandRolesAction(base.TripleOAction):
             return actions.Result(error=six.text_type(exc))
 
         instances = []
-        parameter_defaults = {'HostnameMap': {}}
+        hostname_map = {}
+        parameter_defaults = {'HostnameMap': hostname_map}
         for role in self.roles:
             name = role['name']
             hostname_format = role.get('hostname_format')
@@ -351,12 +354,11 @@ class ExpandRolesAction(base.TripleOAction):
                 # TODO(dtantsur): ordering-dependent logic here, can we do
                 # better?
                 for index, instance in enumerate(role['instances']):
-                    # _validate_instances ensures that either of these is
-                    # not empty
-                    hostname = instance.get('hostname') or instance.get('name')
                     gen_name = (hostname_format.replace('%index%', str(index))
                                 .replace('%stackname%', self.stackname))
-                    parameter_defaults['HostnameMap'][gen_name] = hostname
+                    if 'hostname' not in instance:
+                        instance['hostname'] = gen_name
+                    hostname_map[gen_name] = instance['hostname']
                     instances.append(instance)
             else:
                 count = role.get('count', 1)
@@ -371,7 +373,7 @@ class ExpandRolesAction(base.TripleOAction):
                     if 'profile' in role:
                         inst['profile'] = role['profile']
                     instances.append(inst)
-                    parameter_defaults['HostnameMap'][hostname] = hostname
+                    hostname_map[hostname] = hostname
 
         return {'instances': instances,
                 'environment': {'parameter_defaults': parameter_defaults}}
@@ -390,13 +392,43 @@ class PopulateEnvironmentAction(base.TripleOAction):
         self.ctlplane_network = ctlplane_network
 
     def run(self, context):
+
+        network_keys = (
+            'mtu',
+            'tags',
+        )
+        subnet_keys = (
+            'cidr',
+            'gateway_ip',
+            'host_routes',
+            'dns_nameservers',
+        )
+        resource_registry = self.environment.setdefault(
+            'resource_registry', {})
+        resource_registry.setdefault(
+            'OS::TripleO::DeployedServer::ControlPlanePort',
+            '/usr/share/openstack-tripleo-heat-templates'
+            '/deployed-server/deployed-neutron-port.yaml')
         port_map = (self.environment.setdefault('parameter_defaults', {})
                     .setdefault('DeployedServerPortMap', {}))
         for hostname, nets in self.port_map.items():
-            ctlplane = nets.get(self.ctlplane_network)
-            if not ctlplane:
+            ctlplane_network = nets.get(self.ctlplane_network)
+            if not ctlplane_network:
                 LOG.warning('No ctlplane ports information for %s', hostname)
                 continue
+            fixed_ips = ctlplane_network.get('fixed_ips', [])
+            network_all = ctlplane_network.get('network', {})
+            network = {k: v for k, v in network_all.items()
+                       if k in network_keys}
+            subnets = []
+            for subnet in ctlplane_network.get('subnets', []):
+                subnets.append({k: v for k, v in subnet.items()
+                                if k in subnet_keys})
+            ctlplane = {
+                'fixed_ips': fixed_ips,
+                'network': network,
+                'subnets': subnets
+            }
 
             port_map['%s-%s' % (hostname, self.ctlplane_network)] = ctlplane
 
@@ -408,10 +440,6 @@ def _validate_instances(instances, default_image='overcloud-full'):
         if inst.get('name') and not inst.get('hostname'):
             inst['hostname'] = inst['name']
 
-        if not inst.get('hostname'):
-            raise ValueError('Either hostname or name is required in %s'
-                             % inst)
-
         # Set the default image so that the source validation can succeed.
         inst.setdefault('image', default_image)
 
@@ -423,10 +451,11 @@ def _validate_instances(instances, default_image='overcloud-full'):
         # NOTE(dtantsur): validate image parameters
         _get_source(inst)
 
-        if inst['hostname'] in hostnames:
-            raise ValueError('Hostname %s is used more than once' %
-                             inst['hostname'])
-        hostnames.add(inst['hostname'])
+        if inst.get('hostname'):
+            if inst['hostname'] in hostnames:
+                raise ValueError('Hostname %s is used more than once' %
+                                 inst['hostname'])
+            hostnames.add(inst['hostname'])
 
         if inst.get('name'):
             if inst['name'] in names:
