@@ -135,9 +135,9 @@ class TripleoInventory(object):
             return {}
 
     UNDERCLOUD_SERVICES = [
-        'openstack-nova-compute', 'openstack-heat-engine',
-        'openstack-ironic-conductor', 'openstack-swift-container',
-        'openstack-swift-object', 'openstack-mistral-engine']
+        'tripleo_nova_compute', 'tripleo_heat_engine',
+        'tripleo_ironic_conductor', 'tripleo_swift_container_server',
+        'tripleo_swift_object_server', 'tripleo_mistral_engine']
 
     def get_undercloud_service_list(self):
         """Return list of undercloud services - currently static
@@ -240,6 +240,12 @@ class TripleoInventory(object):
                         hosts[name].update({
                             "%s_ip" % net:
                                 role_net_ip_map[role][net][idx]})
+                    # Add variables for hostname on each network
+                    for net in role_net_hostname_map[role]:
+                        hosts[name].update({
+                            "%s_hostname" % net:
+                                role_net_hostname_map[role][net][idx]})
+
                     networks.update(hosts[name]['enabled_networks'])
 
                 children.append(role)
@@ -287,6 +293,28 @@ class TripleoInventory(object):
         # Associate services with roles
         roles_by_service = self.get_roles_by_service(
             self.stack_outputs.get('EnabledServices', {}))
+
+        # tripleo-groups map to ceph-ansible groups as follows
+        ceph_group_map = {
+            'ceph_mon': 'mons',
+            'ceph_osd': 'osds',
+            'ceph_mgr': 'mgrs',
+            'ceph_rgw': 'rgws',
+            'ceph_mds': 'mdss',
+            'ceph_nfs': 'nfss',
+            'ceph_client': 'clients',
+            'ceph_rbdmirror': 'rbdmirrors',
+            'ceph_grafana-server': 'grafana-server'
+        }
+        # add a ceph-ansible compatible group to the inventory
+        # which has the same roles. E.g. if the inventory has
+        # a group 'ceph_mon' which has childen and vars, then
+        # the inventory will now also have a group 'mons' with
+        # the same children and vars.
+        for service, roles in roles_by_service.copy().items():
+            if service in ceph_group_map.keys():
+                roles_by_service[ceph_group_map[service]] = roles
+
         for service, roles in roles_by_service.items():
             service_children = [role for role in roles
                                 if ret.get(role) is not None]
