@@ -67,6 +67,8 @@ _EXISTING_PASSWORDS = {
     'CephMdsKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'CephManilaClientKey': b'AQANOFFY1NW6AxAAu6jWI3YSOsp2QWusb5Y3DQ==',
     'CephMonKey': b'AQCQXtlXAAAAABAA9l+59N3yH+C49Y0JiKeGFg==',
+    'CephGrafanaAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
+    'CephDashboardAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'SwiftHashSuffix': 'td8mV6k7TYEGKCDvjVBwckpn9',
     'SnmpdReadonlyUserPassword': 'TestPassword',
     'SwiftPassword': 'z6EWAVfW7CuxvKdzjWTdrXCeg',
