@@ -238,6 +238,18 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
                 'ceph_tag': 'v4.0.0-stable-4.0-nautilus-centos-7-x86_64',
+                'ceph_grafana_namespace': 'docker.io/grafana',
+                'ceph_grafana_image': 'grafana',
+                'ceph_grafana_tag': 'latest',
+                'ceph_prometheus_namespace': 'docker.io/prom',
+                'ceph_prometheus_image': 'prometheus',
+                'ceph_prometheus_tag': 'latest',
+                'ceph_alertmanager_namespace': 'docker.io/prom',
+                'ceph_alertmanager_image': 'alertmanager',
+                'ceph_alertmanager_tag': 'latest',
+                'ceph_node_exporter_namespace': 'docker.io/prom',
+                'ceph_node_exporter_image': 'node-exporter',
+                'ceph_node_exporter_tag': 'latest',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
@@ -298,6 +310,18 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_namespace': 'docker.io/cephh',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
+                'ceph_grafana_namespace': 'docker.io/grafana',
+                'ceph_grafana_image': 'grafana',
+                'ceph_grafana_tag': 'latest',
+                'ceph_prometheus_namespace': 'docker.io/prom',
+                'ceph_prometheus_image': 'prometheus',
+                'ceph_prometheus_tag': 'latest',
+                'ceph_alertmanager_namespace': 'docker.io/prom',
+                'ceph_alertmanager_image': 'alertmanager',
+                'ceph_alertmanager_tag': 'latest',
+                'ceph_node_exporter_namespace': 'docker.io/prom',
+                'ceph_node_exporter_image': 'node-exporter',
+                'ceph_node_exporter_tag': 'latest',
                 'name_prefix': 'prefix-',
                 'name_suffix': '-suffix',
                 'tag': 'master',
@@ -638,9 +662,10 @@ class TestPrepare(base.TestCase):
                  'imagename': '192.0.2.0:8787/t/p-nova-compute:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNovaComputeImage': '192.0.2.0:8787/t/p-nova-compute:l',
-                'DockerNovaLibvirtConfigImage': '192.0.2.0:8787/t/'
-                                                'p-nova-compute:l'
+                'ContainerNovaComputeImage':
+                    '192.0.2.0:8787/t/p-nova-compute:l',
+                'ContainerNovaLibvirtConfigImage':
+                    '192.0.2.0:8787/t/p-nova-compute:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -665,7 +690,8 @@ class TestPrepare(base.TestCase):
                  'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNovaLibvirtImage': '192.0.2.0:8787/t/p-nova-libvirt:l'
+                'ContainerNovaLibvirtImage':
+                    '192.0.2.0:8787/t/p-nova-libvirt:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -690,7 +716,8 @@ class TestPrepare(base.TestCase):
                  'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNovaLibvirtImage': '192.0.2.0:8787/t/p-nova-libvirt:l'
+                'ContainerNovaLibvirtImage':
+                    '192.0.2.0:8787/t/p-nova-libvirt:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -716,13 +743,13 @@ class TestPrepare(base.TestCase):
                 'push_destination': '192.0.2.0:8787',
             }],
             'environments/containers-default-parameters.yaml': {
-                'DockerNovaApiImage':
+                'ContainerNovaApiImage':
                 '192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaConfigImage':
+                'ContainerNovaConfigImage':
                 '192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaMetadataConfigImage':
+                'ContainerNovaMetadataConfigImage':
                 u'192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaMetadataImage':
+                'ContainerNovaMetadataImage':
                 '192.0.2.0:8787/t/p-nova-api:l'
             }},
             kb.container_images_prepare(
@@ -751,13 +778,13 @@ class TestPrepare(base.TestCase):
                 'push_destination': '192.0.2.0:8787',
             }],
             'environments/containers-default-parameters.yaml': {
-                'DockerNovaApiImage':
+                'ContainerNovaApiImage':
                 '192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaConfigImage':
+                'ContainerNovaConfigImage':
                 '192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaMetadataConfigImage':
+                'ContainerNovaMetadataConfigImage':
                 u'192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaMetadataImage':
+                'ContainerNovaMetadataImage':
                 '192.0.2.0:8787/t/p-nova-api:l'
             }},
             kb.container_images_prepare(
@@ -783,7 +810,7 @@ class TestPrepare(base.TestCase):
                 'imagename': '192.0.2.0:8787/t/ceph:l',
             }],
             'environments/containers-default-parameters.yaml': {
-                'DockerCephDaemonImage': '192.0.2.0:8787/t/ceph:l'
+                'ContainerCephDaemonImage': '192.0.2.0:8787/t/ceph:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -806,8 +833,8 @@ class TestPrepare(base.TestCase):
                  'imagename': 't/p-neutron-server:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNeutronApiImage': 't/p-neutron-server:l',
-                'DockerNeutronConfigImage': 't/p-neutron-server:l'
+                'ContainerNeutronApiImage': 't/p-neutron-server:l',
+                'ContainerNeutronConfigImage': 't/p-neutron-server:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -836,10 +863,10 @@ class TestPrepare(base.TestCase):
                  'imagename': 't/p-ovn-controller:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNeutronApiImage': 't/p-neutron-server-ovn:l',
-                'DockerNeutronConfigImage': 't/p-neutron-server-ovn:l',
-                'DockerOvnControllerConfigImage': 't/p-ovn-controller:l',
-                'DockerOvnControllerImage': 't/p-ovn-controller:l'
+                'ContainerNeutronApiImage': 't/p-neutron-server-ovn:l',
+                'ContainerNeutronConfigImage': 't/p-neutron-server-ovn:l',
+                'ContainerOvnControllerConfigImage': 't/p-ovn-controller:l',
+                'ContainerOvnControllerImage': 't/p-ovn-controller:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -869,10 +896,11 @@ class TestPrepare(base.TestCase):
                  'imagename': 't/opendaylight:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNeutronApiImage': 't/neutron-server-opendaylight:l',
-                'DockerNeutronConfigImage': 't/neutron-server-opendaylight:l',
-                'DockerOpendaylightApiImage': 't/opendaylight:l',
-                'DockerOpendaylightConfigImage': 't/opendaylight:l',
+                'ContainerNeutronApiImage': 't/neutron-server-opendaylight:l',
+                'ContainerNeutronConfigImage':
+                    't/neutron-server-opendaylight:l',
+                'ContainerOpendaylightApiImage': 't/opendaylight:l',
+                'ContainerOpendaylightConfigImage': 't/opendaylight:l',
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -988,12 +1016,13 @@ class TestPrepare(base.TestCase):
                     '/tht/docker/services/foo.yaml',
                     'OS::TripleO::Services::NovaCompute':
                     '/tht/docker/services/foo.yaml',
-                    'OS::TripleO::Services::OpenShift::Master':
-                    'extraconfig/services/openshift-master.yaml',
+                    'OS::TripleO::Services::OpenShift::Master': 'deployment' +
+                    '/openshift/openshift-master-baremetal-ansible.yaml',
                     'OS::TripleO::Services::Kubernetes::Worker':
-                    'extraconfig/services/kubernetes-worker.yaml',
+                    'deployment' +
+                    'kubernetes/kubernetes-worker-baremetal-ansible.yaml',
                     'OS::TripleO::Services::SkydiveAgent':
-                    'extraconfig/services/skydive-agent.yaml',
+                    'deployment/skydive/skydive-agent-baremetal-ansible.yaml',
                     'OS::TripleO::Services::Noop':
                     'OS::Heat::None'
                 }
