@@ -39,7 +39,8 @@ MOCK_ENABLED_SERVICES = {
     "Compute": [
         "nova_compute",
         "kernel",
-        "tripleo_packages"
+        "tripleo_packages",
+        "ceph_client"
     ],
     "CephStorage": [
         "kernel",
@@ -60,7 +61,7 @@ class TestInventory(base.TestCase):
             {'output_key': 'EnabledServices',
              'output_value': {
                  'Controller': ['sa', 'sb'],
-                 'Compute': ['sd', 'se'],
+                 'Compute': ['sd', 'se', 'ceph_client'],
                  'CustomRole': ['sg', 'sh']}},
             {'output_key': 'KeystoneURL',
              'output_value': 'xyz://keystone'},
@@ -138,6 +139,7 @@ class TestInventory(base.TestCase):
             'keystone': ['Controller'],
             'nova_compute': ['Compute'],
             'cinder_volume': ['BlockStorage'],
+            'ceph_client': ['Compute'],
         }
         self.assertDictEqual(services, expected)
 
@@ -216,12 +218,12 @@ class TestInventory(base.TestCase):
                          'plan': 'overcloud',
                          'project_name': 'admin',
                          'undercloud_service_list': [
-                             'openstack-nova-compute',
-                             'openstack-heat-engine',
-                             'openstack-ironic-conductor',
-                             'openstack-swift-container',
-                             'openstack-swift-object',
-                             'openstack-mistral-engine'],
+                             'tripleo_nova_compute',
+                             'tripleo_heat_engine',
+                             'tripleo_ironic_conductor',
+                             'tripleo_swift_container_server',
+                             'tripleo_swift_object_server',
+                             'tripleo_mistral_engine'],
                          'undercloud_swift_url': 'anendpoint',
                          'username': 'admin'}}}
         inv_list = inventory.list()
@@ -303,12 +305,12 @@ class TestInventory(base.TestCase):
                          'plan': 'overcloud',
                          'project_name': 'admin',
                          'undercloud_service_list': [
-                             'openstack-nova-compute',
-                             'openstack-heat-engine',
-                             'openstack-ironic-conductor',
-                             'openstack-swift-container',
-                             'openstack-swift-object',
-                             'openstack-mistral-engine'],
+                             'tripleo_nova_compute',
+                             'tripleo_heat_engine',
+                             'tripleo_ironic_conductor',
+                             'tripleo_swift_container_server',
+                             'tripleo_swift_object_server',
+                             'tripleo_mistral_engine'],
                          'undercloud_swift_url':
                          'anendpoint' if session else None,
                          'username': 'admin'}}}
@@ -338,7 +340,8 @@ class TestInventory(base.TestCase):
                         'ansible_host': 'y.y.y.1',
                         'ctlplane_ip': 'y.y.y.1',
                         'deploy_server_id': 'd',
-                        'enabled_networks': ['ctlplane']}},
+                        'enabled_networks': ['ctlplane'],
+                        'ctlplane_hostname': 'cp-0.ctlplane.localdomain'}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
                          'serial': 1,
@@ -349,17 +352,20 @@ class TestInventory(base.TestCase):
                         'ansible_host': 'x.x.x.1',
                         'ctlplane_ip': 'x.x.x.1',
                         'deploy_server_id': 'a',
-                        'enabled_networks': ['ctlplane']},
+                        'enabled_networks': ['ctlplane'],
+                        'ctlplane_hostname': 'c-0.ctlplane.localdomain'},
                     'c-1': {
                         'ansible_host': 'x.x.x.2',
                         'ctlplane_ip': 'x.x.x.2',
                         'deploy_server_id': 'b',
-                        'enabled_networks': ['ctlplane']},
+                        'enabled_networks': ['ctlplane'],
+                        'ctlplane_hostname': 'c-1.ctlplane.localdomain'},
                     'c-2': {
                         'ansible_host': 'x.x.x.3',
                         'ctlplane_ip': 'x.x.x.3',
                         'deploy_server_id': 'c',
-                        'enabled_networks': ['ctlplane']}},
+                        'enabled_networks': ['ctlplane'],
+                        'ctlplane_hostname': 'c-2.ctlplane.localdomain'}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
                          'serial': 1,
@@ -370,7 +376,8 @@ class TestInventory(base.TestCase):
                         'ansible_host': 'z.z.z.1',
                         'ctlplane_ip': 'z.z.z.1',
                         'deploy_server_id': 'e',
-                        'enabled_networks': ['ctlplane']}},
+                        'enabled_networks': ['ctlplane'],
+                        'ctlplane_hostname': 'cs-0.ctlplane.localdomain'}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
                          'serial': 1,
@@ -389,6 +396,10 @@ class TestInventory(base.TestCase):
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
             'se': {'children': {'Compute': {}},
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
+            'ceph_client': {'children': {'Compute': {}},
+                            'vars': {'ansible_ssh_user': 'heat-admin'}},
+            'clients': {'children': {'Compute': {}},
+                        'vars': {'ansible_ssh_user': 'heat-admin'}},
             'sg': {'children': {'CustomRole': {}},
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
             'sh': {'children': {'CustomRole': {}},
@@ -408,12 +419,12 @@ class TestInventory(base.TestCase):
                                     'plan': 'overcloud',
                                     'project_name': 'admin',
                                     'undercloud_service_list': [
-                                        'openstack-nova-compute',
-                                        'openstack-heat-engine',
-                                        'openstack-ironic-conductor',
-                                        'openstack-swift-container',
-                                        'openstack-swift-object',
-                                        'openstack-mistral-engine'],
+                                        'tripleo_nova_compute',
+                                        'tripleo_heat_engine',
+                                        'tripleo_ironic_conductor',
+                                        'tripleo_swift_container_server',
+                                        'tripleo_swift_object_server',
+                                        'tripleo_mistral_engine'],
                                     'undercloud_swift_url': 'anendpoint',
                                     'username': 'admin'}}}
         if extra_vars:
