@@ -53,6 +53,9 @@ class Config(object):
                         servers[server_id] = name.lower()
         return servers
 
+    def get_network_config_data(self, stack):
+        return self.stack_outputs.get("HostnameNetworkConfigMap")
+
     def get_deployment_data(self, stack,
                             nested_depth=constants.NESTED_DEPTH):
         deployments = self.client.resources.list(
@@ -123,7 +126,7 @@ class Config(object):
                 whenexpr = [whenexpr]
             for w in whenexpr:
                 # make \|int optional incase forgotten; use only step digit:
-                match = re.search('step(\|int)? == ([0-9]+)$', "%s" % w)
+                match = re.search(r'step(\|int)? == ([0-9]+)$', "%s" % w)
                 if match:
                     if match.group(2) == str(step):
                         return True
@@ -197,11 +200,28 @@ class Config(object):
                            "error {}".format(yaml_file, e))
             raise e
 
+    def render_network_config(self, stack, config_dir, server_roles):
+        network_config = self.get_network_config_data(stack)
+        for server, config in network_config.items():
+            server_deployment_dir = os.path.join(
+                config_dir, server_roles[server], server)
+            self._mkdir(server_deployment_dir)
+            network_config_path = os.path.join(
+                server_deployment_dir, "NetworkConfig")
+            network_config_role_path = os.path.join(
+                config_dir, server_roles[server], "NetworkConfig")
+            s_config = self.client.software_configs.get(config)
+            if getattr(s_config, 'config', ''):
+                with self._open_file(network_config_path) as f:
+                    f.write(s_config.config)
+                with self._open_file(network_config_role_path) as f:
+                    f.write(s_config.config)
+
     def write_config(self, stack, name, config_dir, config_type=None):
         # Get role data:
         role_data = self.stack_outputs.get('RoleData', {})
         role_group_vars = self.stack_outputs.get('RoleGroupVars', {})
-        allnodes_vars = self.stack_outputs.get('AllNodesConfig', {})
+        role_host_vars = self.stack_outputs.get('AnsibleHostVarsMap', {})
         for role_name, role in six.iteritems(role_data):
             role_path = os.path.join(config_dir, role_name)
             self._mkdir(role_path)
@@ -213,6 +233,10 @@ class Config(object):
                     filepath = os.path.join(role_path, 'step_config.pp')
                     with self._open_file(filepath) as step_config:
                         step_config.write(role[config])
+                elif config == 'param_config':
+                    filepath = os.path.join(role_path, 'param_config.json')
+                    with self._open_file(filepath) as param_config:
+                        param_config.write(json.dumps(role[config]))
                 elif config == 'ansible_group_vars':
                     # NOTE(aschultz): ansible group vars are for specific role
                     # services so we merge them in with the others so they
@@ -245,7 +269,10 @@ class Config(object):
 
         role_config = self.get_role_config()
         for config_name, config in six.iteritems(role_config):
-            conf_path = os.path.join(config_dir, config_name + ".yaml")
+            conf_path = os.path.join(config_dir, config_name)
+            # Add .yaml extension only if there's no extension already
+            if '.' not in conf_path:
+                conf_path = conf_path + ".yaml"
             with self._open_file(conf_path) as conf_file:
                 if isinstance(config, list) or isinstance(config, dict):
                     yaml.safe_dump(config, conf_file, default_flow_style=False)
@@ -315,11 +342,6 @@ class Config(object):
                 # We can't have an integer here, let's figure out the
                 # grandparent resource name
                 deployment_ref = deployment.attributes['value']['deployment']
-                warnings.warn('Determining grandparent resource name for '
-                              'deployment %s. Ensure the name property is '
-                              'set on the deployment resource in the '
-                              'templates.' % deployment_ref)
-
                 if '/' in deployment_ref:
                     deployment_stack_id = deployment_ref.split('/')[-1]
                 else:
@@ -332,10 +354,9 @@ class Config(object):
                 deployment_stack = self.client.stacks.get(
                     deployment_stack_id, resolve_outputs=False)
                 parent_stack = deployment_stack.parent
-                grandparent_stack = self.client.stacks.get(
-                    parent_stack, resolve_outputs=False).parent
                 resources = self.client.resources.list(
-                    grandparent_stack,
+                    name,
+                    nested_depth=constants.NESTED_DEPTH,
                     filters=dict(physical_resource_id=parent_stack))
                 if not resources:
                     message = "The deployment resource grandparent name" \
@@ -391,6 +412,13 @@ class Config(object):
                 if deployment_name not in server_pre_deployments:
                     server_pre_deployments.append(deployment_name)
 
+        # Make sure server_roles is populated b/c it won't be if there are no
+        # server deployments.
+        for name, server_id in server_ids.items():
+            server_roles.setdefault(
+                name,
+                self.get_role_from_server_id(stack, server_id))
+
         env, templates_path = self.get_jinja_env(config_dir)
 
         templates_dest = os.path.join(config_dir, 'templates')
@@ -400,12 +428,6 @@ class Config(object):
 
         group_vars_dir = os.path.join(config_dir, 'group_vars')
         self._mkdir(group_vars_dir)
-        # Write allnodes_vars to 'overcloud' group as it doesn't apply
-        # to the undercloud, and 'overcloud' is the inventory group
-        # for all overcloud nodes, regardless of the --stack name.
-        filepath = os.path.join(group_vars_dir, 'overcloud.yaml')
-        with self._open_file(filepath) as vars_file:
-            yaml.safe_dump(allnodes_vars, vars_file, default_flow_style=False)
 
         host_vars_dir = os.path.join(config_dir, 'host_vars')
         self._mkdir(host_vars_dir)
@@ -469,18 +491,32 @@ class Config(object):
                                default_flow_style=False)
 
         # Render host_vars
-        for server, deployments in server_deployment_names.items():
+        for server in server_names.values():
             host_var_server_path = os.path.join(host_vars_dir, server)
             host_var_server_template = env.get_template('host_var_server.j2')
+            role = server_roles[server]
+            ansible_host_vars = (
+                yaml.safe_dump(
+                    role_host_vars[role][server],
+                    default_flow_style=False) if role_host_vars else None)
+
+            pre_deployments = server_deployment_names.get(
+                server, {}).get('pre_deployments', [])
+            post_deployments = server_deployment_names.get(
+                server, {}).get('post_deployments', [])
 
             with open(host_var_server_path, 'w') as f:
                 template_data = host_var_server_template.render(
-                    role=server_roles[server],
-                    pre_deployments=deployments['pre_deployments'],
-                    post_deployments=deployments['post_deployments'])
+                    role=role,
+                    pre_deployments=pre_deployments,
+                    post_deployments=post_deployments,
+                    ansible_host_vars=ansible_host_vars)
                 self.validate_config(template_data, host_var_server_path)
                 f.write(template_data)
 
+        # Render NetworkConfig data
+        self.render_network_config(stack, config_dir, server_roles)
+
         shutil.copyfile(
             os.path.join(templates_path, 'deployments.yaml'),
             os.path.join(config_dir, 'deployments.yaml'))
