@@ -13,15 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import collections
+import re
 
 from glanceclient import exc as exceptions
 from glanceclient.v2.client import Client as real_glance_client
 
 
-def create_or_find_kernel_and_ramdisk(glanceclient, kernel_name, ramdisk_name,
-                                      kernel_path=None, ramdisk_path=None,
-                                      skip_missing=False):
+def create_or_find_kernel_and_ramdisk(glanceclient, kernel_name, ramdisk_name):
     """Find or create a given kernel and ramdisk in Glance.
 
     If either kernel_path or ramdisk_path is None, they will not be created,
@@ -30,23 +28,20 @@ def create_or_find_kernel_and_ramdisk(glanceclient, kernel_name, ramdisk_name,
     :param glanceclient: A client for Glance.
     :param kernel_name: Name to search for or create for the kernel.
     :param ramdisk_name: Name to search for or create for the ramdisk.
-    :param kernel_path: Path to the kernel on disk.
-    :param ramdisk_path: Path to the ramdisk on disk.
-    :param skip_missing: If `True', do not raise an exception if either the
-                         kernel or ramdisk image is not found.
 
     :returns: A dictionary mapping kernel or ramdisk to the ID in Glance.
     """
-    kernel_image = _upload_file(glanceclient, kernel_name, kernel_path,
-                                'aki', 'Kernel', skip_missing=skip_missing)
-    ramdisk_image = _upload_file(glanceclient, ramdisk_name, ramdisk_path,
-                                 'ari', 'Ramdisk', skip_missing=skip_missing)
-    return {'kernel': kernel_image.id, 'ramdisk': ramdisk_image.id}
+    kernel_image = _check_image(glanceclient, kernel_name, disk_format='aki',
+                                image_type='Kernel')
+    ramdisk_image = _check_image(glanceclient, ramdisk_name, disk_format='ari',
+                                 image_type='Ramdisk')
+    return {'kernel': kernel_image, 'ramdisk': ramdisk_image}
 
 
-def _upload_file(glanceclient, name, path, disk_format, type_name,
-                 skip_missing=False):
-    image_tuple = collections.namedtuple('image', ['id'])
+def _check_image(glanceclient, name, disk_format, image_type):
+    if re.match(r'^(file|https?)://', name):
+        return name
+
     try:
         if isinstance(glanceclient, real_glance_client):
             images = glanceclient.images.list(name=name,
@@ -56,8 +51,7 @@ def _upload_file(glanceclient, name, path, disk_format, type_name,
                 if ((img['name'] == name or img['id'] == name) and
                         img['disk_format'] == disk_format):
                     image = img
-            if not image:
-                raise exceptions.NotFound("No image found")
+                    break
         else:
             # TODO(dprince) remove this
             # This code expects the python-openstackclient version of
@@ -67,14 +61,10 @@ def _upload_file(glanceclient, name, path, disk_format, type_name,
             image = glanceclient.images.find(name=name,
                                              disk_format=disk_format)
     except exceptions.NotFound:
-        if path:
-            image = glanceclient.images.create(
-                name=name, disk_format=disk_format, is_public=True,
-                data=open(path, 'rb'))
-        else:
-            if skip_missing:
-                image = image_tuple(None)
-            else:
-                raise ValueError("%s image not found in Glance, and no path "
-                                 "specified." % type_name)
-    return image
+        image = None
+
+    if image:
+        return image.id
+    else:
+        raise ValueError("%s image %s not found in Glance" % (image_type,
+                                                              name))
